/*
 * Copyright © 2014 Canonical Ltd.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 3 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef POWER_STATE_CHANGE_REASON_H_
#define POWER_STATE_CHANGE_REASON_H_

enum class PowerStateChangeReason
{
    unknown = 0,
    inactivity = 1,
    power_key = 2,
    proximity = 3,
    notification = 4,
    snap_decision = 5,
    call_done = 6
};

#endif
